PostgresConnection

Struct PostgresConnection 

pub struct PostgresConnection { /* private fields */ }
Connection wrapper for Postgres/Tokio Postgres client.

Manages the client handle and background task used to drive the connection and implements Executor for running queries against Postgres.