pub struct PostgresConnection { /* private fields */ }Trait Implementations
Sourceimpl Connection for PostgresConnection
impl Connection for PostgresConnection
Sourceasync fn connect(url: Cow<'static, str>) -> Result<PostgresConnection>
async fn connect(url: Cow<'static, str>) -> Result<PostgresConnection>
Create a connection (or pool) with at least one underlying session
established to the given URL.
Sourcefn begin(&mut self) -> impl Future<Output = Result<PostgresTransaction<'_>>>
fn begin(&mut self) -> impl Future<Output = Result<PostgresTransaction<'_>>>
Begin a transaction scope tied to the current connection.
async fn disconnect(self) -> Result<()>
Sourceimpl Debug for PostgresConnection
impl Debug for PostgresConnection
Sourceimpl Executor for PostgresConnection
impl Executor for PostgresConnection
Sourcetype Driver = PostgresDriver
type Driver = PostgresDriver
Underlying driver type supplying SQL dialect + I/O.
Sourceasync fn prepare(&mut self, sql: String) -> Result<Query<Self::Driver>>
async fn prepare(&mut self, sql: String) -> Result<Query<Self::Driver>>
Prepare a query (e.g. statement caching / parameter binding) returning a
Query. Read moreSourcefn run<'s>(
&'s mut self,
query: impl AsQuery<Self::Driver> + 's,
) -> impl Stream<Item = Result<QueryResult>> + Send
fn run<'s>( &'s mut self, query: impl AsQuery<Self::Driver> + 's, ) -> impl Stream<Item = Result<QueryResult>> + Send
Run an already prepared query, streaming heterogeneous
QueryResult items. Read moreSourcefn fetch<'s>(
&'s mut self,
query: impl AsQuery<Self::Driver> + 's,
) -> impl Stream<Item = Result<RowLabeled>> + Send + 's
fn fetch<'s>( &'s mut self, query: impl AsQuery<Self::Driver> + 's, ) -> impl Stream<Item = Result<RowLabeled>> + Send + 's
Run a query and stream only labeled rows, filtering out non-row results. Read more